@@ -23,13 +23,17 @@ class MultiCurl:
             curl_commands_string (str): A string containing multiple cURL commands separated by 'curl '.
         """
         # Parse the curl_commands_string into a list of Curl instances
-        command_tails = [cmd.strip() for cmd in curl_commands_string.split('curl ') if cmd.strip()]
+        command_tails = [cmd.strip().rstrip(';') for cmd in curl_commands_string.split('curl ') if cmd.strip()]
         self.curls = []
         for tail in command_tails:
             full_command = "curl " + tail
-            # Extract URL: use shlex to split and take the last argument as URL
+            # Extract URL: find the first non-option argument after 'curl'
             command_list = shlex.split(full_command)
-            url = command_list[-1] if len(command_list) > 1 else ""
+            url = ""
+            for arg in command_list[1:]:
+                if not arg.startswith('-'):
+                    url = arg
+                    break
             self.curls.append(Curl(url=url, curl=full_command))
     
     def run(self, delay: float = 0, url_filter: str = None):
@@ -65,7 +69,10 @@ class MultiCurl:
             )
             curl.response = result.stdout
             curl.error = result.stderr.strip() if result.stderr else ""
-            print(f"Response length: {len(curl.response)}")
+            if result.returncode != 0:
+                print(f"Error running command: {curl.error}")
+            else:
+                print(f"Response length: {len(curl.response)}, text: {curl.response[:100]}")
             time.sleep(delay)
         
         print("All matching commands executed.")
